[tor-commits] [stem/master] Torture English a little less

atagar at torproject.org atagar at torproject.org
Sun Apr 12 01:52:30 UTC 2015


commit d66a8491adffe8fd1c1562daa5ee390d4ed8c681
Author: Damian Johnson <atagar at torproject.org>
Date:   Sat Apr 11 18:50:43 2015 -0700

    Torture English a little less
    
    I've been treating presently as a synonym of currently. It isn't. While it's
    fun to watch Roger weep openly, I've had my fun. Time to find something new to
    make him writhe.
---
 docs/faq.rst                                 |    2 +-
 run_tests.py                                 |    2 +-
 stem/__init__.py                             |    4 ++--
 stem/control.py                              |   26 +++++++++++++-------------
 stem/descriptor/hidden_service_descriptor.py |    2 +-
 stem/descriptor/remote.py                    |    2 +-
 stem/interpreter/commands.py                 |    2 +-
 stem/interpreter/settings.cfg                |    2 +-
 stem/response/events.py                      |    2 +-
 stem/socket.py                               |    2 +-
 stem/util/system.py                          |    2 +-
 test/integ/descriptor/remote.py              |    2 +-
 12 files changed, 25 insertions(+), 25 deletions(-)

diff --git a/docs/faq.rst b/docs/faq.rst
index 81f1597..2a4ec83 100644
--- a/docs/faq.rst
+++ b/docs/faq.rst
@@ -512,7 +512,7 @@ How can I test compatibility with multiple python versions?
 -----------------------------------------------------------
 
 Stem supports python versions 2.6 and above, including the 3.x series. You can
-test all versions of python you presently have installed on your system with
+test all versions of python you currently have installed on your system with
 `tox <https://testrun.org/tox/>`_. If you're using a Debian based system this
 can be as simple as...
 
diff --git a/run_tests.py b/run_tests.py
index 8f70d09..c7ac574 100755
--- a/run_tests.py
+++ b/run_tests.py
@@ -59,7 +59,7 @@ https://pypi.python.org/pypi/mock/
 """
 
 NEW_CAPABILITIES_FOUND = """\
-Your version of Tor has capabilities stem presently isn't taking advantage of.
+Your version of Tor has capabilities stem currently isn't taking advantage of.
 If you're running the latest version of stem then please file a ticket on:
 
   https://trac.torproject.org/projects/tor/wiki/doc/stem/bugs
diff --git a/stem/__init__.py b/stem/__init__.py
index 5339342..4752a99 100644
--- a/stem/__init__.py
+++ b/stem/__init__.py
@@ -70,7 +70,7 @@ Library for working with the tor process.
   **NAMED**         relay can be referred to by its nickname
   **RUNNING**       relay is currently usable
   **STABLE**        relay's suitable for long-lived circuits
-  **UNNAMED**       relay isn't presently bound to a nickname
+  **UNNAMED**       relay isn't currently bound to a nickname
   **V2DIR**         relay supports the v2 directory protocol
   **VALID**         relay has been validated
   ================= ===========
@@ -133,7 +133,7 @@ Library for working with the tor process.
   **TORPROTOCOL**           violation in the tor protocol
   **INTERNAL**              internal error
   **REQUESTED**             requested by the client via a TRUNCATE command
-  **HIBERNATING**           relay is presently hibernating
+  **HIBERNATING**           relay is currently hibernating
   **RESOURCELIMIT**         relay is out of memory, sockets, or circuit IDs
   **CONNECTFAILED**         unable to contact the relay
   **OR_IDENTITY**           relay had the wrong OR identification
diff --git a/stem/descriptor/hidden_service_descriptor.py b/stem/descriptor/hidden_service_descriptor.py
index fec17e4..31a99cc 100644
--- a/stem/descriptor/hidden_service_descriptor.py
+++ b/stem/descriptor/hidden_service_descriptor.py
@@ -299,7 +299,7 @@ class HiddenServiceDescriptor(Descriptor):
       elif authentication_type == STEALTH_AUTH:
         content = HiddenServiceDescriptor._decrypt_stealth_auth(content, authentication_cookie)
       else:
-        raise DecryptionFailure("Unrecognized authentication type '%s', presently we only support basic auth (%s) and stealth auth (%s)" % (authentication_type, BASIC_AUTH, STEALTH_AUTH))
+        raise DecryptionFailure("Unrecognized authentication type '%s', currently we only support basic auth (%s) and stealth auth (%s)" % (authentication_type, BASIC_AUTH, STEALTH_AUTH))
 
       if not content.startswith(b'introduction-point '):
         raise DecryptionFailure('Unable to decrypt the introduction-points, maybe this is the wrong key?')
diff --git a/stem/descriptor/remote.py b/stem/descriptor/remote.py
index effe3ca..4d3423d 100644
--- a/stem/descriptor/remote.py
+++ b/stem/descriptor/remote.py
@@ -653,7 +653,7 @@ class DirectoryAuthority(object):
      Added the is_bandwidth_authority attribute.
 
   :var str nickname: nickname of the authority
-  :var str address: IP address of the authority, presently they're all IPv4 but
+  :var str address: IP address of the authority, currently they're all IPv4 but
     this may not always be the case
   :var int or_port: port on which the relay services relay traffic
   :var int dir_port: port on which directory information is available
diff --git a/stem/interpreter/commands.py b/stem/interpreter/commands.py
index f065110..4047517 100644
--- a/stem/interpreter/commands.py
+++ b/stem/interpreter/commands.py
@@ -260,7 +260,7 @@ class ControlInterpretor(code.InteractiveConsole):
 
     if not arg:
       status = 'enabled' if self._run_python_commands else 'disabled'
-      return format('Python support is presently %s.' % status, *STANDARD_OUTPUT)
+      return format('Python support is currently %s.' % status, *STANDARD_OUTPUT)
     elif arg.lower() == 'enable':
       self._run_python_commands = True
     elif arg.lower() == 'disable':
diff --git a/stem/interpreter/settings.cfg b/stem/interpreter/settings.cfg
index ce78ba7..290e646 100644
--- a/stem/interpreter/settings.cfg
+++ b/stem/interpreter/settings.cfg
@@ -40,7 +40,7 @@ msg.startup_banner
 |For more information run '/help'.
 |
 
-msg.tor_unavailable Tor isn't running and the command presently isn't in your PATH.
+msg.tor_unavailable Tor isn't running and the command currently isn't in your PATH.
 
 msg.starting_tor
 |Tor isn't running. Starting a temporary Tor instance for our interpreter to
diff --git a/stem/response/events.py b/stem/response/events.py
index 20676c6..47d6a0f 100644
--- a/stem/response/events.py
+++ b/stem/response/events.py
@@ -621,7 +621,7 @@ class GuardEvent(Event):
 
 class HSDescEvent(Event):
   """
-  Event triggered when we fetch a hidden service descriptor that presently isn't in our cache.
+  Event triggered when we fetch a hidden service descriptor that currently isn't in our cache.
 
   The HS_DESC event was introduced in tor version 0.2.5.2-alpha.
 
diff --git a/stem/socket.py b/stem/socket.py
index 344e1a0..8024098 100644
--- a/stem/socket.py
+++ b/stem/socket.py
@@ -208,7 +208,7 @@ class ControlSocket(object):
   def connection_time(self):
     """
     Provides the unix timestamp for when our socket was either connected or
-    disconnected. That is to say, the time we connected if we're presently
+    disconnected. That is to say, the time we connected if we're currently
     connected and the time we disconnected if we're not connected.
 
     .. versionadded:: 1.3.0
diff --git a/stem/util/system.py b/stem/util/system.py
index f42951d..c263ce3 100644
--- a/stem/util/system.py
+++ b/stem/util/system.py
@@ -158,7 +158,7 @@ def is_gentoo():
 
 def is_bsd():
   """
-  Checks if we are within the BSD family of operating systems. This presently
+  Checks if we are within the BSD family of operating systems. This currently
   recognizes Macs, FreeBSD, and OpenBSD but may be expanded later.
 
   :returns: **bool** to indicate if we're on a BSD OS
diff --git a/test/integ/descriptor/remote.py b/test/integ/descriptor/remote.py
index 4c7779b..4a9cd9b 100644
--- a/test/integ/descriptor/remote.py
+++ b/test/integ/descriptor/remote.py
@@ -155,7 +155,7 @@ class TestDescriptorDownloader(unittest.TestCase):
 
     # TODO: method needs to be fixed - not quite sure what's going wrong...
 
-    test.runner.skip(self, '(test presently broken)')
+    test.runner.skip(self, '(test currently broken)')
     return
 
     downloader = stem.descriptor.remote.DescriptorDownloader(validate = True)



More information about the tor-commits mailing list
diff --git a/stem/control.py b/stem/control.py
index 4308eca..c4cbc0b 100644
--- a/stem/control.py
+++ b/stem/control.py
@@ -83,9 +83,9 @@ If you're fine with allowing your script to raise exceptions then this can be mo
     |- get_pid - provides the pid of our tor process
     |
     |- get_microdescriptor - querying the microdescriptor for a relay
-    |- get_microdescriptors - provides all presently available microdescriptors
+    |- get_microdescriptors - provides all currently available microdescriptors
     |- get_server_descriptor - querying the server descriptor for a relay
-    |- get_server_descriptors - provides all presently available server descriptors
+    |- get_server_descriptors - provides all currently available server descriptors
     |- get_network_status - querying the router status entry for a relay
     |- get_network_statuses - provides all preently available router status entries
     |
@@ -125,7 +125,7 @@ If you're fine with allowing your script to raise exceptions then this can be mo
     |- close_stream - close a stream
     |
     |- signal - sends a signal to the tor client
-    |- is_newnym_available - true if tor would presently accept a NEWNYM signal
+    |- is_newnym_available - true if tor would currently accept a NEWNYM signal
     |- get_newnym_wait - seconds until tor would accept a NEWNYM signal
     |- get_effective_rate - provides our effective relaying rate limit
     |- is_geoip_unavailable - true if we've discovered our geoip db to be unavailable
@@ -357,7 +357,7 @@ UNCACHEABLE_GETCONF_PARAMS = (
 # is unavailable
 GEOIP_FAILURE_THRESHOLD = 5
 
-SERVER_DESCRIPTORS_UNSUPPORTED = "Tor is presently not configured to retrieve \
+SERVER_DESCRIPTORS_UNSUPPORTED = "Tor is currently not configured to retrieve \
 server descriptors. As of Tor version 0.2.3.25 it downloads microdescriptors \
 instead unless you set 'UseMicrodescriptors 0' in your torrc."
 
@@ -598,7 +598,7 @@ class BaseController(object):
   def connection_time(self):
     """
     Provides the unix timestamp for when our socket was either connected or
     disconnected. That is to say, the time we connected if we're presently
     connected and the time we disconnected if we're not connected.
 
     .. versionadded:: 1.3.0
@@ -1537,7 +1537,7 @@ class Controller(BaseController):
     """
     get_microdescriptors(default = UNDEFINED)
 
     Provides an iterator for all of the microdescriptors that tor presently
     knows about.
 
     **Tor does not expose this information via the control protocol**
@@ -1650,7 +1650,7 @@ class Controller(BaseController):
     """
     get_server_descriptors(default = UNDEFINED)
 
     Provides an iterator for all of the server descriptors that tor presently
     knows about.
 
     **As of Tor version 0.2.3.25 relays no longer get server descriptors by
@@ -1776,7 +1776,7 @@ class Controller(BaseController):
     get_network_statuses(default = UNDEFINED)
 
     Provides an iterator for all of the router status entries that tor
-    presently knows about.
+    currently knows about.
 
     This provides
     :class:`~stem.descriptor.router_status_entry.RouterStatusEntryMicroV3`
@@ -2688,7 +2688,7 @@ class Controller(BaseController):
     """
     get_circuit(circuit_id, default = UNDEFINED)
 
     Provides a circuit presently available from tor.
 
     :param int circuit_id: circuit to be fetched
     :param object default: response if the query fails
@@ -2706,7 +2706,7 @@ class Controller(BaseController):
       if circ.id == circuit_id:
         return circ
 
-    raise ValueError("Tor presently does not have a circuit with the id of '%s'" % circuit_id)
+    raise ValueError("Tor currently does not have a circuit with the id of '%s'" % circuit_id)
 
   @with_default()
   def get_circuits(self, default = UNDEFINED):
@@ -3004,12 +3004,12 @@ class Controller(BaseController):
 
   def is_newnym_available(self):
     """
     Indicates if tor would presently accept a NEWNYM signal. This can only
     account for signals sent via this controller.
 
     .. versionadded:: 1.2.0
 
     :returns: **True** if tor would presently accept a NEWNYM signal, **False**
       otherwise
     """
 
@@ -3175,7 +3175,7 @@ class Controller(BaseController):
   def _attach_listeners(self):
     """
     Attempts to subscribe to the self._event_listeners events from tor. This is
     a no-op if we're not presently authenticated.
 
     :returns: tuple of the form (set_events, failed_events)
 
@@ -598,7 +598,7 @@ class BaseController(object):
     """
     Provides the unix timestamp for when our socket was either connected or
-    disconnected. That is to say, the time we connected if we're presently
+    disconnected. That is to say, the time we connected if we're currently
     connected and the time we disconnected if we're not connected.
 
@@ -1537,7 +1537,7 @@ class Controller(BaseController):
     get_microdescriptors(default = UNDEFINED)
 
-    Provides an iterator for all of the microdescriptors that tor presently
+    Provides an iterator for all of the microdescriptors that tor currently
     knows about.
 
@@ -1650,7 +1650,7 @@ class Controller(BaseController):
     get_server_descriptors(default = UNDEFINED)
 
-    Provides an iterator for all of the server descriptors that tor presently
+    Provides an iterator for all of the server descriptors that tor currently
     knows about.
 
@@ -2688,7 +2688,7 @@ class Controller(BaseController):
     get_circuit(circuit_id, default = UNDEFINED)
 
-    Provides a circuit presently available from tor.
+    Provides a circuit currently available from tor.
 
     :param int circuit_id: circuit to be fetched
@@ -3004,12 +3004,12 @@ class Controller(BaseController):
   def is_newnym_available(self):
     """
-    Indicates if tor would presently accept a NEWNYM signal. This can only
+    Indicates if tor would currently accept a NEWNYM signal. This can only
     account for signals sent via this controller.
 
@@ -3004,12 +3004,12 @@ class Controller(BaseController):
     .. versionadded:: 1.2.0
 
-    :returns: **True** if tor would presently accept a NEWNYM signal, **False**
+    :returns: **True** if tor would currently accept a NEWNYM signal, **False**
       otherwise
     """
@@ -3175,7 +3175,7 @@ class Controller(BaseController):
     """
     Attempts to subscribe to the self._event_listeners events from tor. This is
-    a no-op if we're not presently authenticated.
+    a no-op if we're not currently authenticated.
 
     :returns: tuple of the form (set_events, failed_events)